
#ifndef _C1_pr41_
#define _C1_pr41_

#ifdef __cplusplus
extern "C" {
#endif

extern void F41_1509(EIF_REFERENCE, EIF_INTEGER_32, EIF_REFERENCE, EIF_REFERENCE);
extern void EIF_Minit41(void);

#ifdef __cplusplus
}
#endif

#endif
